#!/usr/bin/ruby

# Key: d6c60c8e688e0afa7f49416897aadc1f
# Encryption method: AES-128-ECB

# Note: Pre-treatment of the base64 string may be necessary to make it usable by some base64 decoding methods.
#   - All occurrences of "-" (minus) must be changed to "+" (plus)
#   - All occurrences of "_" (underscore) must be changed to "/" (slash)
#   - All occurrences of "%20%20" must be removed or converted to carriage return + linefeed or just linefeed.
#   - The length of the string, after whitespace has been removed, must be evenly divisible by 4. If it is not,
#     add one or two "=" (equals) characters to make it evenly divisible by 4.

require 'openssl'
require 'base64'

def standardizeBase64(nonstandardBase64)
  nonstandardBase64 = nonstandardBase64.gsub('-', '+')
  nonstandardBase64 = nonstandardBase64.gsub('_', '/')
  nonstandardBase64 = nonstandardBase64.gsub('%20%20', '')
  nonstandardBase64 = nonstandardBase64 << '=' * ((4 - (nonstandardBase64.length % 4)) % 4)
  return nonstandardBase64
end

key="d6c60c8e688e0afa7f49416897aadc1f" # 128-bit/16-byte key, represented as series of sixteen hex doubles

atdataEqsValue = 'AeZFhZnm_ytYdj06wE5ikO4vPv302-SG9Osx_itiNbxF4gIY3CHdBpvpxd6Jaxvx%20%207i8-_fTb5Ib06zH-K2I1vEXiAhjcId0Gm-nF3olrG_HuLz799NvkhvTrMf4rYjW8%20%20rJmJDtsRTiTCWYfZfF6SDcHuTfwpOhubzIEAFNIeJRoOtRe-zev31MASpLRr2A_g%20%20wGPEJDvSZnokppAKPaWe2w'
printf "URL-friendly EQS: %s\n", atdataEqsValue

b64CipherText = standardizeBase64(atdataEqsValue)
printf "Standardized B64: %s\n", b64CipherText

encryptedBinary = Base64.decode64(b64CipherText)

cipher = OpenSSL::Cipher::AES.new(128, :ECB)
cipher.padding = 16
cipher.decrypt
cipher.key = [key].pack('H*') # Key assignment has to happen after .decrypt
clearText = cipher.update(encryptedBinary) + cipher.final
clearText.strip

printf "Clear text: %s\n", clearText

